
From: Gerrit Huizenga <gh@us.ibm.com>

Fix compile warnings. Delete dead code.

Signed-Off-By: Matt Helsley <matthltc@us.ibm.com>
Signed-Off-By: Gerrit Huizenga <gh@us.ibm.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 include/linux/ckrm_ce.h          |    2 +-
 include/linux/ckrm_rc.h          |    5 -----
 kernel/ckrm/ckrm.c               |    5 ++---
 kernel/ckrm/ckrm_numtasks.c      |    2 +-
 kernel/ckrm/rbce/rbce_internal.h |    2 +-
 kernel/ckrm/rbce/rbce_main.c     |    2 +-
 6 files changed, 6 insertions(+), 12 deletions(-)

diff -puN include/linux/ckrm_ce.h~ckrm-fix-compile-warnings-and-delete-dead-code include/linux/ckrm_ce.h
--- 25/include/linux/ckrm_ce.h~ckrm-fix-compile-warnings-and-delete-dead-code	Wed Jul 13 14:44:52 2005
+++ 25-akpm/include/linux/ckrm_ce.h	Wed Jul 13 14:44:52 2005
@@ -78,7 +78,7 @@ struct rbce_eng_callback {
 extern int ckrm_register_engine(const char *name, struct ckrm_eng_callback *);
 extern int ckrm_unregister_engine(const char *name);
 
-extern void *ckrm_classobj(char *, int *classtype);
+extern void *ckrm_classobj(const char * classname, int *classtype);
 
 extern int rcfs_register_engine(struct rbce_eng_callback *);
 extern int rcfs_unregister_engine(struct rbce_eng_callback *);
diff -puN include/linux/ckrm_rc.h~ckrm-fix-compile-warnings-and-delete-dead-code include/linux/ckrm_rc.h
--- 25/include/linux/ckrm_rc.h~ckrm-fix-compile-warnings-and-delete-dead-code	Wed Jul 13 14:44:52 2005
+++ 25-akpm/include/linux/ckrm_rc.h	Wed Jul 13 14:44:52 2005
@@ -227,11 +227,6 @@ extern int ckrm_init_core_class(struct c
 				const char *name);
 extern int ckrm_release_core_class(struct ckrm_core_class *);
 
-/* TODO: can disappear after cls del debugging */
-
-extern struct ckrm_res_ctlr *ckrm_resctlr_lookup(struct ckrm_classtype *type,
-						 const char *resname);
-
 extern void ckrm_lock_hier(struct ckrm_core_class *);
 extern void ckrm_unlock_hier(struct ckrm_core_class *);
 extern struct ckrm_core_class *ckrm_get_next_child(struct ckrm_core_class *,
diff -puN kernel/ckrm/ckrm.c~ckrm-fix-compile-warnings-and-delete-dead-code kernel/ckrm/ckrm.c
--- 25/kernel/ckrm/ckrm.c~ckrm-fix-compile-warnings-and-delete-dead-code	Wed Jul 13 14:44:52 2005
+++ 25-akpm/kernel/ckrm/ckrm.c	Wed Jul 13 14:44:52 2005
@@ -65,7 +65,7 @@ inline unsigned int ckrm_is_res_regd(str
 /*
  * Return non-zero if the given core class pointer is valid.
  */
-struct ckrm_res_ctlr *ckrm_resctlr_lookup(struct ckrm_classtype *clstype,
+static struct ckrm_res_ctlr *ckrm_resctlr_lookup(struct ckrm_classtype *clstype,
 					  const char *resname)
 {
 	int resid = -1;
@@ -83,10 +83,9 @@ struct ckrm_res_ctlr *ckrm_resctlr_looku
 	return NULL;
 }
 
-EXPORT_SYMBOL_GPL(ckrm_resctlr_lookup);
 
 /* given a classname return the class handle and its classtype*/
-void *ckrm_classobj(char *classname, int *classtype_id)
+void *ckrm_classobj(const char *classname, int *classtype_id)
 {
 	int i;
 
diff -puN kernel/ckrm/ckrm_numtasks.c~ckrm-fix-compile-warnings-and-delete-dead-code kernel/ckrm/ckrm_numtasks.c
--- 25/kernel/ckrm/ckrm_numtasks.c~ckrm-fix-compile-warnings-and-delete-dead-code	Wed Jul 13 14:44:52 2005
+++ 25-akpm/kernel/ckrm/ckrm_numtasks.c	Wed Jul 13 14:44:52 2005
@@ -501,7 +501,7 @@ static int numtasks_set_config(void *my_
 	if (!res)
 		return -EINVAL;
 
-	while ((p = strsep(&cfgstr, ",")) != NULL) {
+	while ((p = strsep((char**)&cfgstr, ",")) != NULL) {
 		substring_t args[MAX_OPT_ARGS];
 		int token;
 		if (!*p)
diff -puN kernel/ckrm/rbce/rbce_internal.h~ckrm-fix-compile-warnings-and-delete-dead-code kernel/ckrm/rbce/rbce_internal.h
--- 25/kernel/ckrm/rbce/rbce_internal.h~ckrm-fix-compile-warnings-and-delete-dead-code	Wed Jul 13 14:44:52 2005
+++ 25-akpm/kernel/ckrm/rbce/rbce_internal.h	Wed Jul 13 14:44:52 2005
@@ -247,7 +247,7 @@ extern struct rbce_private_data *create_
 						     *, int);
 extern bitvector_t *get_gl_mask_vecs(int);
 extern struct rbce_class *find_class_name(const char *);
-extern struct rbce_class *get_class(char *classname, int *classtype);
+extern struct rbce_class *get_class(const char *classname, int *classtype);
 extern void put_class(struct rbce_class *);
 extern void free_all_private_data(void);
 
diff -puN kernel/ckrm/rbce/rbce_main.c~ckrm-fix-compile-warnings-and-delete-dead-code kernel/ckrm/rbce/rbce_main.c
--- 25/kernel/ckrm/rbce/rbce_main.c~ckrm-fix-compile-warnings-and-delete-dead-code	Wed Jul 13 14:44:52 2005
+++ 25-akpm/kernel/ckrm/rbce/rbce_main.c	Wed Jul 13 14:44:52 2005
@@ -211,7 +211,7 @@ struct rbce_class *create_rbce_class(con
 	return cls;
 }
 
-struct rbce_class *get_class(char *classname, int *classtype)
+struct rbce_class *get_class(const char *classname, int *classtype)
 {
 	struct rbce_class *cls;
 	void *classobj;
_
